@@ -15,11 +15,8 @@
 """Unit tests for googleapiclient._helpers."""
 
 import unittest
-
-import mock
-
-import six
-from six.moves import urllib
+from unittest import mock
+import urllib
 
 from googleapiclient import _helpers
 
